This glossary defines a number of common terms used throughout the documentation. For the definition of framework components consult the API docs.

* AEA: an Autonomous Economic Agent (AEA) is a "an intelligent agent acting on an owner's behalf, with limited or no interference, and whose goal is to generate economic value to its owner". AEAs are a special type of agent.

* (Software) Agent: a software agent is a computer program that acts on behalf of an entity (e.g. individual, organisation, business).
